@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2015 Matthias Geier
+# Copyright (c) 2014-2019 Matthias Geier
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 http://jackclient-python.readthedocs.io/
 
 """
-__version__ = '0.4.4'
+__version__ = '0.4.6'
 
 from ctypes.util import find_library as _find_library
 import errno as _errno
@@ -1778,13 +1778,17 @@ class OwnMidiPort(MidiPort, OwnPort):
         event : buffer
             The actual MIDI event data.
 
+            .. warning:: The buffer is re-used (and therefore
+               overwritten) between iterations.  If you want to keep the
+               data beyond the current iteration, please make a copy.
+
         """
         event = self._event
         buf = _lib.jack_port_get_buffer(self._ptr, self._client.blocksize)
         for i in range(_lib.jack_midi_get_event_count(buf)):
             err = _lib.jack_midi_event_get(event, buf, i)
-            # TODO: proper error handling if this ever happens:
-            assert not err, err
+            if err:
+                break
             yield event.time, _ffi.buffer(event.buffer, event.size)
 
     def clear_buffer(self):
